@@ -17,7 +17,11 @@ sub my_options {
         max_score => [
             'integer',
             undef,
-            "Maximum value of the signal graph feature's \"score\" attribute."]
+            "Maximum value of the signal graph feature's \"score\" attribute."],
+        flip_sign => [
+            'boolean',
+            0,
+            "Optionally flip the signal for wigfileB (if the scores are positive but we wish to paint the signal along negative y-axis)"]
     };
 }
 
@@ -67,14 +71,21 @@ sub draw {
  my ($left,$top,$right,$bottom) = $self->calculate_boundaries($dx,$dy);
  my $height   = $bottom - $top;
  my $feature  = $self->feature;
+ my $set_flip = $self->option('flip_sign') | 0;
  
  
- #Draw individual features for reads (they unlike wiggle features will have scores)
+ #Draw individual features for reads (unlike wiggle features reads will have scores)
  my $t_id = $feature->method;
  if($t_id && $t_id eq $self->_check_uni){return Bio::Graphics::Glyph::generic::draw_component($self,@_);}
 
- #Draw dual graph if we don't have a score
- my @wiggles = ($feature->attributes('wigfileA'),$feature->attributes('wigfileB'));
+ #Draw multiple graph if we don't have a score
+ my @wiggles = ();
+ foreach ('A'..'Z') {
+   my $filename = 'wigfile'.$_;
+   my ($wiggle) = $feature->attributes('wigfile'.$_);
+   push (@wiggles, $wiggle);
+ }
+
  my ($fasta)   = $feature->attributes('fasta');
  my($scale,$y_origin,$min_score,$max_score);
 
@@ -82,11 +93,16 @@ sub draw {
 
  #Depending on what we have (wiggle or BigWig) pick the way to paint the signal graph
  for(my $w = 0; $w < @wiggles; $w++){
-  if($w > 0){$self->configure(-pos_color, NEGCOL);}
-  else{$self->configure(-pos_color, POSCOL);}
+  if ($w > 0) {
+    $self->configure(-pos_color, NEGCOL);
+    $self->configure(-no_grid, 1);
+  } else {
+    $self->configure(-pos_color, POSCOL);
+  }
   if ($wiggles[$w] =~ /\.wi\w{1,3}$/) {
    $self->draw_wigfile($feature,$wiggles[$w],@_);
   } elsif ($wiggles[$w] =~ /\.bw$/ && $fasta) {
+   my $flip = ($w > 0 && $set_flip) ? -1 : 1;
    use Bio::DB::BigWig 'binMean';
    use Bio::DB::Sam;
    my $wig = Bio::DB::BigWig->new(-bigwig => "$wiggles[$w]",
@@ -96,6 +112,7 @@ sub draw {
                                   -start  => $self->panel->start,
                                   -end    => $self->panel->end,
                                   -type   => 'summary');
+   
    my $stats = $summary->statistical_summary($self->width);
    my @vals  = map {$_->{validCount} ? $_->{sumData}/$_->{validCount}:0} @$stats;
    $self->draw_coverage($self,\@vals,@_);
@@ -167,8 +184,10 @@ recognized:
 
  wigfileB    path name    Path to a Bio::Graphics::Wiggle file for max values in 10-base bins
 
+ fasta       path name    Path to fasta file to enable BigWig drawing
+
  u_method    method name  Use method of [method name] to identify individual features (like alignment matches) 
-                          to show at high zoom level. By default it is set to 'match'
+                          to show at high zoom level. By default it is set to 'match'    
 
 =head1 BUGS
 
